/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package rmk.core;

import java.io.FileOutputStream;
import java.io.PrintStream;

/**
 * Prints the results of a Testplan to STDOUT.
 *
 * @author christoph
 */
public class Printer {

	private TestPlan testplan;

	public Printer(TestPlan testplan) {
		this.testplan = testplan;
	}

	public void print() {
		String s = mkString();
		printStdout(s);
		if(testplan.saveResult) {
			printFile(s);
		}
	}

	private String mkString() {
		String s = "";

		s +=
			"++++++ Rihamark Testplan ++++++\n\n" +
			"Name of testplan: " + testplan.toString()
		;

		for(Test test: testplan.getTestsToRun()) {
			int numOfImages = -1;
			if(test.getRuns().size() > 0) {
				numOfImages = test.getRuns().element().getResults().size();
			}

			s +=
				"\n\n------ Test ------\n" +
				"\nName of test: " + test + "\n" +
				"Test Type: " + test.testType + "\n" +
				"Image Folder: " + test.getImageDir() + "\n" +
				"Attack Image Folder: " + test.getImageAttackDir() + "\n" +
				"Number of images: " + numOfImages
			;

			for(Run run: test.getRuns()) {
				s +=
					"\n\n~~~~~~ Run ~~~~~~\n\n" +
					run.toString() + "\n" +
					"Time elapsed: " + run.getElapsedTimeSec() + " sec.\n" +
					"Mean Distance: " + run.getMeanDistance() + "\n\n"
				;

				for(Result res: run.getResults()) {
					s +=
						res.pathA.toString() + "\t||\t" + res.pathB.toString() + "\t||\t" + res.distance + "\n"
					;
				}

				s += "\n~~~~~~ End of Run ~~~~~~";
			}

			s += "\n\n------ End of Test ------";
		}

		s += "\n\n++++++ End of Rihamark Testplan ++++++\n";

		return s;
	}

	private void printStdout(String s) {
		System.out.println(s);
	}

	private void printFile(String s) {
		FileOutputStream out;
		PrintStream p;

		try
		{
				out = new FileOutputStream(testplan.resultPath);
				p = new PrintStream(out);
				p.print(s);
				p.close();
		}
		catch (Exception e)
		{
				Debug.debugPrint(Debug.LogLevel.ERR, e, "Could not write the testplan result file to disk.");
		}
	}
	
} // end of class
