/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TODO Implement toString methods for the names of Attacks, Tests, ...
 * TODO Create abstraction class for attacks to run. (this one should contain the LinkedList)
 */

package rmk.core;

import rmk.core.Debug;
import java.io.File;
import java.util.LinkedList;
import org.simpleframework.xml.*;

/**
 * The testplan to run. Only one instance of a testplan is possible at a
 * given time.
 */
@Root
public class TestPlan {

	// All the tests of a testplan
	@ElementList
	private LinkedList<Test> testsToRun = new LinkedList<Test>();
	@Attribute
	private String name = "Name of Testplan";
	@Element
	public File resultPath = new File(System.getProperty("java.io.tmpdir") + File.separator + "rihamark_testplan_log.txt");
	@Element
	public String resultFormat = "ASCII";
	@Element
	public boolean saveResult = true;
	@Element
	private boolean deletePreviousResults = true;

	public enum ItemType {TEST, ATTACK, ALGORITHM};

	public void addTest() {
	    Debug.debugPrint("Adding a new test to testplan.");
	    Test test = new Test();
	    testsToRun.add(test);
	}

	public void removeTest() {
		throw new UnsupportedOperationException();
	}

	protected void deleteResults() {
		for(Test test: testsToRun) {
			test.getRuns().clear();
		}
	}

	@Override
	public String toString() {
		return getName();
	}

	public int getNumOfTests() {
		return testsToRun.size();
	}

	/**
	 * A job is defined as the number of attacks and algorithms
	 * a dispatcher has to run.
	 *
	 * @return
	 */
	public int getNumOfJobs() {
		int numOfJobs = 0;
		
		for(Test t: testsToRun) {
			if(t.isProcessAttackChain()) numOfJobs += t.getAttacksToRun().size();
			numOfJobs += t.getAlgorithmsToRun().size();
		}
		
		return numOfJobs;
	}


	/*****************************/
	/* getter and setter methods */
	/*****************************/


	/**
	 * @return the deletePreviousResults
	 */
	public boolean isDeletePreviousResults() {
		return deletePreviousResults;
	}

	/**
	 * @param deletePreviousResults the deletePreviousResults to set
	 */
	public void setDeletePreviousResults(boolean deletePreviousResults) {
		this.deletePreviousResults = deletePreviousResults;
	}

	public LinkedList<Test> getTestsToRun() {
		return this.testsToRun;
	}

	// FIXME REMOVE
	public void setTestsToRun(LinkedList<Test> testsToRun) {
		this.testsToRun = testsToRun;
	}

	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}

} // end of class

