/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.gui;

import java.awt.FlowLayout;
import java.util.ArrayList;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import rmk.SPArguments.*;
import rmk.SPInterfaces.Attack;

/**
 *
 * @author christoph
 */
public class GuiTestItem extends JPanel {

	Attack attack;
	ArrayList<SPArgument> spArguments;
	// "pointers" to the GUI controls of the arguments
	ArrayList<JComponent> controls = new ArrayList<JComponent>();

	// all the components (incl. glues, fillers, layouts) that
	// are generated on the fly by createControls().
	ArrayList<JComponent> jComponents = new ArrayList<JComponent>();

	private javax.swing.JButton buttonSave;

	public GuiTestItem(TestItem testItem) {
		spArguments = testItem.getSpArguments();

		createControls();
		initComponents();
	}

	private void initComponents() {
		
		/* start: create the static controls */

		buttonSave = new javax.swing.JButton();
		buttonSave.setText("Save");
        buttonSave.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				buttonSaveActionPerformed(evt);
			}
        });

		/* end: create the static controls */

		// bring it all together

		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
		for(JComponent jComponent: jComponents) {
			add(jComponent);
		}
		JPanel jPanel = new JPanel(new FlowLayout());
		jPanel.add(buttonSave);
		add(jPanel);
	}

    /**
     * Save button pressed.
	 *
     * @param evt
     */
    private void buttonSaveActionPerformed(java.awt.event.ActionEvent evt) {
		saveControls();
    }


	/****************************/
	/* START: SAVE THE CONTROLS */
	/****************************/


	private void saveControls() {
		int idx = 0;
		for(SPArgument uiControl: spArguments) {
			saveControl(uiControl, idx);
			idx++;
		}
	}

	private void saveControl(SPArgument spArgument, int controlIdx) {
		if(spArgument instanceof CheckBox) {
			saveCheckBox((CheckBox)spArgument, controlIdx);
		} else if(spArgument instanceof ComboBox) {
			saveComboBox((ComboBox)spArgument, controlIdx);
		} else if(spArgument instanceof SpinnerInt) {
			saveSpinnerInt((SpinnerInt)spArgument, controlIdx);
		} else if(spArgument instanceof SpinnerDbl) {
			saveSpinnerDbl((SpinnerDbl)spArgument, controlIdx);
		}
	}

	private void saveCheckBox(CheckBox checkBox, int controlIdx) {
		// retrieve the actual value from the GUI control
		Boolean newValue = ((JCheckBox)controls.get(controlIdx)).isSelected();
		
		// save the value to the spArgument object
		checkBox.setValue(newValue);
	}

	private void saveComboBox(ComboBox comboBox, int controlIdx) {
		// retrieve
		JComboBox jComboBox = (JComboBox)controls.get(controlIdx);
		String newValue = jComboBox.getModel().getSelectedItem().toString();

		// save
		comboBox.setValue(newValue);
	}

	private void saveSpinnerInt(SpinnerInt spinner, int controlIdx) {
		// retrieve
		JSpinner jSpinner = (JSpinner)controls.get(controlIdx);
		Integer newValue = ((SpinnerNumberModel)jSpinner.getModel()).getNumber().intValue();

		// save
		spinner.setValue(newValue);
	}

	private void saveSpinnerDbl(SpinnerDbl spinner, int controlIdx) {
		// retrieve
		JSpinner jSpinner = (JSpinner)controls.get(controlIdx);
		Double newValue = ((SpinnerNumberModel)jSpinner.getModel()).getNumber().doubleValue();

		// save
		spinner.setValue(newValue);
	}


	/**************************/
	/* END: SAVE THE CONTROLS */
	/**************************/

	
	/*******************************************/
	/* START: INITIAL CREATION OF THE CONTROLS */
	/*******************************************/

	
	private void createControls() {
		for(SPArgument spArgument: spArguments) {
			createControl(spArgument);
		}
	}

	private void createControl(SPArgument spArgument) {
		
		if(spArgument instanceof CheckBox) {
			createCheckBox((CheckBox)spArgument);
		} else if(spArgument instanceof ComboBox) {
			createComboBox((ComboBox)spArgument);
		} else if(spArgument instanceof SpinnerInt) {
			createSpinnerInt((SpinnerInt)spArgument);
		} else if(spArgument instanceof SpinnerDbl) {
			createSpinnerDbl((SpinnerDbl)spArgument);
		} else if(spArgument instanceof Label) {
			createLabel((Label)spArgument);
		}
	}

	/**
	 * Lays out the supplied components in a row.
	 *
	 * @param jComponents The components to lay out.
	 * @return
	 */
	private JComponent layoutComponents(JComponent... jComponents) {
		FlowLayout flowLayout = new FlowLayout(FlowLayout.LEFT);
		JPanel jPanel = new JPanel(flowLayout);

		for(JComponent jComponent: jComponents) {
			jPanel.add(jComponent);
		}

		jPanel.add(Box.createHorizontalGlue());
		return jPanel;
	}

	private void createCheckBox(CheckBox checkBox) {
		JCheckBox component = new javax.swing.JCheckBox();
		String label = checkBox.getLabel();
		boolean isSelected = checkBox.getValue();

		component.setText(label);
		component.setSelected(isSelected);

		controls.add(component);
		jComponents.add(layoutComponents(component));
	}

	private void createComboBox(ComboBox comboBox) {
		JComboBox component = new JComboBox();
		String[] items = comboBox.getItems();
		String selectedItem = comboBox.getValue();

		DefaultComboBoxModel defaultComboBoxModel = new DefaultComboBoxModel(items);
		defaultComboBoxModel.setSelectedItem(selectedItem);
		component.setModel(defaultComboBoxModel);

		JLabel jLabel = new JLabel(comboBox.getLabel());

		controls.add(component);
		jComponents.add(layoutComponents(jLabel, component));
	}

	private void createSpinnerInt(SpinnerInt spinner) {
		int angle = spinner.getValue();

		SpinnerNumberModel spinnerNumberModel = new SpinnerNumberModel(angle, spinner.getMinimum(), spinner.getMaximum(), spinner.getStepSize());
		JSpinner component = new JSpinner(spinnerNumberModel);

		JLabel jLabel = new JLabel(spinner.getLabel());

		controls.add(component);
		jComponents.add(layoutComponents(jLabel, component));
	}

	private void createSpinnerDbl(SpinnerDbl spinner) {
		double angle = spinner.getValue();

		SpinnerNumberModel spinnerNumberModel = new SpinnerNumberModel(angle, spinner.getMinimum(), spinner.getMaximum(), spinner.getStepSize());
		JSpinner component = new JSpinner(spinnerNumberModel);

		JLabel jLabel = new JLabel(spinner.getLabel());

		controls.add(component);
		jComponents.add(layoutComponents(jLabel, component));
	}

	private void createLabel(Label label) {
		JLabel component = new JLabel(label.getValue());

		controls.add(component);
		jComponents.add(layoutComponents(component));
	}


	/*******************************************/
	/* END: INITIAL CREATION OF THE COMPONENTS */
	/*******************************************/

	
} // end of class

