/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TODO
 *   - Implement logging (maybe use Logger from Java SE).
 */

package rmk.gui;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;
import org.jdesktop.application.Application;
import org.jdesktop.application.SingleFrameApplication;
import rmk.core.Debug;

/**
 * The main class of the application.
 */
public class RihamarkApp extends SingleFrameApplication {

	/**
	 * Force to come up in the System L&F. See
	 * http://java.sun.com/docs/books/tutorial/uiswing/lookandfeel/plaf.html
	 * for more information.
	 */
	private static void setLookAndFeel() {
//		String lookAndFeel = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";
//		String lookAndFeel = UIManager.getSystemLookAndFeelClassName();
		String lookAndFeel = UIManager.getCrossPlatformLookAndFeelClassName();

		try {
			UIManager.setLookAndFeel(lookAndFeel);
		} catch (Exception ex) {
			Debug.debugPrint(Debug.LogLevel.ERR, "Unsupported Look and Feel: " + lookAndFeel);
		}
	}

	protected RihamarkView rihamarkView;

    /**
     * At startup create and show the main frame of the application.
     */
    @Override protected void startup() {
		rihamarkView = new RihamarkView(this);
        show(rihamarkView);
    }

    /**
     * This method is to initialize the specified window by injecting resources.
     * Windows shown in our application come fully initialized from the GUI
     * builder, so this additional configuration is not needed.
     */
    @Override protected void configureWindow(java.awt.Window root) {
    }

    /**
     * A convenient static getter for the application instance.
     * @return the instance of RihamarkApp
     */
    public static RihamarkApp getApplication() {
        return Application.getInstance(RihamarkApp.class);
    }

    /**
     * Main method launching the application.
     */
    public static void main(String[] args) {
		setLookAndFeel();
        launch(RihamarkApp.class, args);
    }
}
