/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.algorithms.pHash;

import java.util.ArrayList;
import org.simpleframework.xml.*;
import rmk.SPArguments.SPArgument;

import rmk.core.Debug;
import java.io.File;
import org.pHash.DCTImageHash;
import org.pHash.pHash;
import rmk.SPInterfaces.Algorithm;
import rmk.core.DCTHash;
import rmk.core.Hash;
import rmk.core.Test;
import rmk.SPArguments.*;

public class DCT extends Algorithm {

	private static String name = "DCT Based Image Hash";
	private static String bundleName = "pHash";
	private static String description =
			"Fast inter testing: Supported";

	/* start: service provider options */
	@Element private String label = "No options for algorithm DCT available.";
	/* end: service provider options */

	public DCT() {
		super(name, bundleName, description, true);
		Debug.debugPrint(Debug.LogLevel.DEBUG2,"Constructor in " + this.getClass().getCanonicalName());

		if(!deserialization) {
			// argument
			addSPArgument(new Label(label));
		}
	}

	@Override
	public Hash getHash(File file) {
		long hashValue = pHash.getDCTImageHash(file).getHash();
		DCTHash hash = new DCTHash(hashValue);

		return hash;
	}

	@Override
	public double cmpHashes(Hash hashA, Hash hashB) {
		DCTImageHash phHashA = new DCTImageHash();
		DCTImageHash phHashB = new DCTImageHash();

		phHashA.setHash(((DCTHash)hashA).getHashValue());
		phHashB.setHash(((DCTHash)hashB).getHashValue());

		return pHash.getDCTImageHashDistance(phHashA, phHashB);
	}

	public double cmpImages(File fileA, File fileB) {
		return pHash.getDCTImageHashDistance(fileA.toString(), fileB.toString());
	}

} // end of class

