/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.analyzers.jFree;

import java.awt.geom.Rectangle2D;
import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.apache.batik.dom.GenericDOMImplementation;
import org.apache.batik.svggen.SVGGraphics2D;
import org.jfree.chart.JFreeChart;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.Document;

/**
 *
 * @author christoph
 */
public class PrintChartSVG {

	/**
	* Saves a chart to a SVG file.
	*
	* @param out the output stream.
	* @param chart the chart.
	* @param width the chart width.
	* @param height the chart height.
	*
	*/
	public static void saveChartAsSVG
	(
			File file,
			JFreeChart chart,
			int width,
			int height
	)
	{
	// THE FOLLOWING CODE BASED ON THE EXAMPLE IN THE BATIK DOCUMENTATION...

	// Get a DOMImplementation
	DOMImplementation domImpl = GenericDOMImplementation.getDOMImplementation();
	// Create an instance of org.w3c.dom.Document
	Document document = domImpl.createDocument(null, "svg", null);
	// Create an instance of the SVG Generator
	SVGGraphics2D svgGenerator = new SVGGraphics2D(document);
	// set the precision to avoid a null pointer exception in Batik 1.5
	svgGenerator.getGeneratorContext().setPrecision(6);
	// Ask the chart to render into the SVG Graphics2D implementation
	chart.draw(svgGenerator, new Rectangle2D.Double(0, 0, width, height), null);
	// Finally, stream out SVG to a file using UTF-8 character to
	// byte encoding
	boolean useCSS = true;

	try {
		Writer out = new OutputStreamWriter(new FileOutputStream(file), "UTF-8");
		svgGenerator.stream(out, useCSS);
	} catch (Exception ex) {
		Logger.getLogger(PrintChartSVG.class.getName()).log(Level.SEVERE, null, ex);
		return;
	}

	}
	
}  // end of class

